@@ -105,7 +105,7 @@ def run():
 
 
     if options.list_tasks:
-        logging.error("No tasks to execute. Please choose from: ")
+        console.confirm("Please choose from: ")
         printTasks()
         sys.exit(0)
 
